@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 package App::RouterColorizer;
-$App::RouterColorizer::VERSION = '1.223120';
+$App::RouterColorizer::VERSION = '1.223500';
 use Moose;
 
 use feature 'signatures';
@@ -496,7 +496,7 @@ s/^ ( \| \s+ \| ) ( \Q Optical Return Loss \E \( \QdB\E \) ) ( \s+ \| \s+ ) ( $B
         $1.$self->_colorize($2, $RED).$3.$self->_colorize($4, $RED).$5/exx;
 
     # alarm show
-    $line =~ s/ ^ ( \| ) ( \s+ [0-9]* ) ( \| ) ( \s+ ) ( \| ) ( [^|]+ ) ( \| ) ( \s+ [0-9]+ )
+    $line =~ s/ ^ ( \| ) ( \s* [0-9]* ) ( \| ) ( \s+ ) ( \| ) ( [^|]+ ) ( \| ) ( \s+ [0-9]+ )
                   ( \| ) ( \s* $BIGALARMS|$LITTLEALARMS \s* ) ( \| ) ( [^|]+ ) ( \| ) ( [^|]+ )
                   ( \| ) ( \s+ $BIGOVERRIDES \s+ ) ( \| ) $/
         $1.$self->_colorize($2, $ORANGE).
@@ -508,7 +508,7 @@ s/^ ( \| \s+ \| ) ( \Q Optical Return Loss \E \( \QdB\E \) ) ( \s+ \| \s+ ) ( $B
         $13.$self->_colorize($14, $ORANGE).
         $15.$self->_colorize($16, $ORANGE).
         $17/exx;
-    $line =~ s/ ^ ( \| ) ( \s+ [0-9]* ) ( \| ) ( \s+ ) ( \| ) ( [^|]+ ) ( \| ) ( \s+ [0-9]+ )
+    $line =~ s/ ^ ( \| ) ( \s* [0-9]* ) ( \| ) ( \s+ ) ( \| ) ( [^|]+ ) ( \| ) ( \s+ [0-9]+ )
                   ( \| ) ( \s* $BIGALARMS|$LITTLEALARMS \s* ) ( \| ) ( [^|]+ ) ( \| ) ( [^|]+ ) ( \| ) ( [^|]+ ) ( \| ) $/
         $1.$self->_colorize($2, $RED).
         $3.$self->_colorize($4, $RED).
@@ -688,7 +688,7 @@ App::RouterColorizer - Colorize router CLI output
 
 =head1 VERSION
 
-version 1.223120
+version 1.223500
 
 =head1 DESCRIPTION
 
